#ifndef __UDS_SERVICE_H_
#define __UDS_SERVICE_H_
/*
#define ServiceID_DiagnosticSessionControl 0x10
#define ServiceID_ECUReset 0x11
#define ServiceID_SecurityAccess 0x27
#define ServiceID_ReadDataByIdentifier 0x22
#define ServiceID_WriteDataByIdentifier 0x2E
#define ServiceID_TesterPresent 0x3E

typedef enum
{
    TransferEnd = 0,
    TransferStart,
} e_TransferStatus;

typedef enum
{
    Tx_NoAct = 0,
    Tx_SF,
    Tx_FF,
    Tx_CF,
    Tx_End,
} e_TxType;

typedef struct
{
    unsigned char ServiceID;
    e_TransferStatus TransferStatus;
    unsigned int DataLen;
    unsigned char Data[64];
} s_UDS_ServiceBuffer;

void SetRxTransferStatus(e_TransferStatus sts, unsigned int UDS_Len);
unsigned char GetRxTransferDataNumber(void);
void TransferServiceRxInfo(unsigned char *Data, unsigned char len);

void UDS_ServiceMain(void);

void SetServiceProc(unsigned char ServiceID, unsigned int ServiceDID);

e_TxType TransferServiceTxInfo(s_UDS_Msg_Buffer *buffer);
*/
#endif
